pub struct BPE {
pub dropout: Option<f32>,
pub unk_token: Option<String>,
pub continuing_subword_prefix: Option<String>,
pub end_of_word_suffix: Option<String>,
pub fuse_unk: bool,
pub byte_fallback: bool,
pub ignore_merges: bool,
/* private fields */
}Expand description
A Byte Pair Encoding model.
Fields
dropout: Option<f32>Dropout probability for merges. 0.0 = no dropout is the default. At 1.0, tokenization will perform no merges, so the result will just be characters.
unk_token: Option<String>The unknown token to be used when we encounter an unknown char
continuing_subword_prefix: Option<String>An optional prefix to use on any subword that exist only behind another one
end_of_word_suffix: Option<String>An optional suffix to caracterize and end-of-word subword
fuse_unk: boolDo multiple unk tokens get fused
byte_fallback: boolByte fallback from sentence pieces, instead of UNK, uses "<0x00>"
for each byte in the unk token
ignore_merges: boolWhether or not to direct output words if they are part of the vocab.
Implementations
Sourceimpl BPE
impl BPE
Sourcepub fn builder() -> BpeBuilder
pub fn builder() -> BpeBuilder
Initialize a BpeBuilder.
Sourcepub fn new(vocab: Vocab, merges: Merges) -> Self
pub fn new(vocab: Vocab, merges: Merges) -> Self
Create a new BPE model with the given vocab and merges.
Sourcepub fn from_file(vocab: &str, merges: &str) -> BpeBuilder
pub fn from_file(vocab: &str, merges: &str) -> BpeBuilder
Initialize a BpeBuilder model from vocab and merges files
Sourcepub fn read_file(vocab: &str, merges: &str) -> Result<(Vocab, Merges)>
pub fn read_file(vocab: &str, merges: &str) -> Result<(Vocab, Merges)>
Read the given files to extract the vocab and merges
Sourcepub fn clear_cache(&self)
pub fn clear_cache(&self)
Reset the cache.
Sourcepub fn resize_cache(&mut self, capacity: usize)
pub fn resize_cache(&mut self, capacity: usize)
Resize the cache
pub fn get_vocab(&self) -> Vocab
pub fn get_unk_token(&self) -> &Option<String>
pub fn get_continuing_subword_prefix(&self) -> &Option<String>