BpeTrainer

Struct BpeTrainer 

#[non_exhaustive]
pub struct BpeTrainer { pub min_frequency: u64, pub vocab_size: usize, pub show_progress: bool, pub special_tokens: Vec<AddedToken>, pub limit_alphabet: Option<usize>, pub initial_alphabet: AHashSet<char>, pub continuing_subword_prefix: Option<String>, pub end_of_word_suffix: Option<String>, pub max_token_length: Option<usize>, /* private fields */ }
In charge of training a BPE model

Examples

use tokenizers::tokenizer::Trainer;
use tokenizers::models::bpe::{BPE, BpeTrainer};

let sequences = vec![ "Hello", "World" ];

let mut trainer = BpeTrainer::default();
trainer.feed(sequences.iter(), |s| Ok(vec![s.to_owned()]));

let mut model = BPE::default();
let special_tokens = trainer.train(&mut model).unwrap();

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
min_frequency: u64

The minimum frequency a pair must have to produce a merge operation

vocab_size: usize

The target vocabulary size

show_progress: bool

Whether to show progress while training

special_tokens: Vec<AddedToken>

A list of special tokens that the model should know of

limit_alphabet: Option<usize>

Whether to limit the number of initial tokens that can be kept before computing merges

initial_alphabet: AHashSet<char>

The initial alphabet we want absolutely to include. This allows to cover some characters that are not necessarily in the training set

continuing_subword_prefix: Option<String>

An optional prefix to use on any subword that exist only behind another one

end_of_word_suffix: Option<String>

An optional suffix to characterize and end-of-word subword

max_token_length: Option<usize>

An optional parameter to limit the max length of any single token

Implementations

Source

impl BpeTrainer

pub fn new(min_frequency: u64, vocab_size: usize) -> Self

pub fn builder() -> BpeTrainerBuilder

pub fn do_train( &self, word_counts: &AHashMap<CompactString, u64>, model: &mut BPE, ) -> Result<Vec<AddedToken>>