#[non_exhaustive]pub struct WordLevelTrainer {
pub min_frequency: u64,
pub vocab_size: usize,
pub show_progress: bool,
pub special_tokens: Vec<AddedToken>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.min_frequency: u64The minimum frequency a word must have to be part of the vocabulary
vocab_size: usizeThe target vocabulary size
show_progress: boolWhether to show progress while training
special_tokens: Vec<AddedToken>A list of special tokens that the model should know of
Implementations
Sourceimpl WordLevelTrainer
impl WordLevelTrainer
pub fn builder() -> WordLevelTrainerBuilder