pub enum Sequence {
A,
B,
}Expand description
Represents any sequences received as input of the PostProcessor
Variants
A
This is the first sequence, the one that is always specified
B
This is the pair sequence, that is optional